@@ -1,4 +1,4 @@
-from typing import Callable, Dict, Sequence
+from typing import Callable, Dict, Sequence, Union
 
 import torch as t
 from torch.utils.data import DataLoader
@@ -9,7 +9,7 @@ DEVICE = t.device("cuda" if t.cuda.is_available() else "cpu")
 
 def evaluate(
     model: t.nn.Module, dataloader: DataLoader, metric_functions: Sequence[MetricFunc]
-) -> Dict[str, float]:
+) -> Dict[str, Union[float, t.Tensor]]:
     model.eval()
 
     _, tmp = next(iter(dataloader))
@@ -27,8 +27,11 @@ def evaluate(
             outputs = t.cat((outputs, batch_outputs))
             targets = t.cat((targets, batch_targets))
 
-    metrics: Dict[str, float] = {}
+    metrics: Dict[str, Union[float, t.Tensor]] = {}
     for metric_func in metric_functions:
         metrics[metric_func.__name__] = metric_func(targets, outputs)
 
+    metrics["outputs"] = outputs
+    metrics["targets"] = targets
+
     return metrics
