@@ -44,8 +44,11 @@ class CsvMLRun(MLRun):
         if path.exists(self._summary_filename):
             raise RuntimeError(f"{self._summary_filename} was already written once!")
         summary = {"hyperparams": hparams, "evaluation_metrics": metrics}
-        with open(self._summary_filename, "wt") as f:
-            json.dump(summary, f)
+        try:
+            with open(self._summary_filename, "wt") as f:
+                json.dump(summary, f)
+        except Exception as e:
+            logger.error("Unable to write summary!", exc_info=e)
 
     def log_metric(self, step: int, name: str, val: float) -> None:
         print(f"{datetime.now()},{step},{name},{val:.6f}", file=self._metricsfile)
